package X3D::Components::Gtk2;
use strict;
use warnings;

use rlib "X3D/Components/Gtk2";
use rlib "X3D/Components/Gtk2/Nodes";

#Abstract node types
use X3DGtk2Bin;
use X3DGtk2Node;

#Node set
use Gtk2Main;
use Gtk2OutlineEditor;
use Gtk2Window;

1;
__END__
